﻿using System;
using System.Collections.Generic;
using System.Linq;
using System.Text;

/* This file contains some helper functions for the various MediaFrame classes.
 * These are defined here rather than in MediaFrameTypes.cs because that file
 * was automatically generated from the XML schema (using Microsoft's XSD.EXE tool).
 */

public partial class RegisteredType
{
    public override string ToString()
    {
        return string.Format("{0}/{1}", categoryField, formatField);
    }
}

public partial class URI
{
    public override string ToString()
    {
        return string.Format("{0},{1}", urlField.ToString(), typeField.ToString());
    }
}

public partial class URL
{
    public override string ToString()
    {
        return string.Format("{0}/{1}/{2}/{3}", domainField, deviceField, locationField, assetIdField);
    }
}

public partial class TemporalURI : URI
{
    public override string ToString()
    {
        string segmentStr = segmentField == null ? "" : segmentField.ToString();
        return string.Format("{0}[{1}]", base.ToString(), segmentStr);
    }
}

public partial class TemporalSegment
{

    public override string ToString()
    {
        long start = TimeSpan.Parse(startField.Time).Ticks;
        long offset = TimeSpan.Parse(offsetField.TimeSpan).Ticks;
        long duration = TimeSpan.Parse(durationField.TimeSpan).Ticks;
        return string.Format("{0}:{1}:{2}:{3}", start, offset, duration, startField.Rate.Ticks);
    }
}

public partial class URN
{
    public override string ToString()
    {
        return Guid;
    }
}

public partial class ValueType
{
    public override string ToString()
    {
        return itemField == null ? "" : itemField.ToString();
    }
}

public partial class FieldDescription
{
    public override string ToString()
    {
        return string.Format("{0}.{1} [{2}]", nameField.Table, nameField.Name, datatypeField);
    }
}

public partial class Keyword
{
    public Keyword()
    {
    }

    public Keyword(string id, string phrase, string startTime, double rate, string duration, string tcStart, string tcEnd, string imagePath)
    {
        Id = id;
        Phrase = phrase;
        Start = new TemporalPoint();
        Start.Time = startTime;
        Start.Rate = new TemporalSampleRate();
        Start.Rate.Ticks = rate;
        Duration = new TemporalSpan();
        Duration.TimeSpan = duration;
        Duration.SampleRate = new TemporalSampleRate();
        Duration.SampleRate.Ticks = rate;
        TimecodeStart = tcStart;
        TimecodeEnd = tcEnd;
        ImagePath = imagePath;
    }

    public override string ToString()
    {
        return string.Format("'{0}' ({1}-{2}) [{3}]", Phrase, TimecodeStart, TimecodeEnd, Id);
    }

}

public partial class MediaFrameEvent
{
    public override string ToString()
    {
        return string.Format("S/N={0}, type={1}", SerialNumber, EventType);
    }
}

public partial class AssetEvent
{
    public override string ToString()
    {
        return string.Format("{0} [event={1}, URI={2}]", base.ToString(), this.Event, this.Uri);
    }
}

public partial class MetadataEvent
{
    public override string ToString()
    {
        return string.Format("{0} [event={1}, URN={2}]", base.ToString(), Event, Urn);
    }
}

public partial class PropertyType
{
    public PropertyType()
    {
    }
    
    public PropertyType(ItemChoiceType itemType, string key, object value)
    {
        Value = new ValueType();
        Value.ItemElementName = itemType;
        Key = key;
        Value.Item = value;
    }
}

public partial class MetadataFilter
{
    public MetadataFilter()
    {
    }

    public MetadataFilter(string filterString)
    {
        Type = "Metadata";
        Filter = filterString;
    }
}